%define        libname  lib%{name}

Name:          ntfs-3g_ntfsprogs
Version:       2022.10.3
Release:       1mamba
Epoch:         1
Summary:       A read-write NTFS driver
Group:         System/Kernel and Hardware/Drivers
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://www.tuxera.com/company/open-source/
Source:        http://tuxera.com/opensource/ntfs-3g_ntfsprogs-%{version}.tgz
Source1:       ntfs-3g-policy
Patch:         ntfs-3g-2010.3.6-nomtab.patch
License:       GPL
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libhwinfo-devel
BuildRequires: libuuid-devel
## AUTOBUILDREQ-END
BuildRequires: libfuse-devel
BuildRequires: hwinfo-devel >= 22.1

%description
The NTFS-3G driver is an open source, GPL licensed, third generation Linux NTFS driver for 32-bit, little-endian architectures which was implemented by the Linux-NTFS project.
It provides full read-write access to NTFS, excluding access to encrypted files, writing compressed files, changing file ownership, access right.

Technically it's based on and a major improvement to the third generation Linux NTFS driver, ntfsmount.
The improvements includes functionality, quality and performance enhancements.

%package -n ntfs-3g
Summary:       A read-write NTFS driver
Group:         System/Kernel and Hardware/Drivers
Requires:      %{libname} = %{?epoch:%epoch:}%{version}-%{release}
Requires:      fuse

%description -n ntfs-3g
The NTFS-3G driver is an open source, GPL licensed, third generation Linux NTFS driver for 32-bit, little-endian architectures which was implemented by the Linux-NTFS project.
It provides full read-write access to NTFS, excluding access to encrypted files, writing compressed files, changing file ownership, access right.

Technically it's based on and a major improvement to the third generation Linux NTFS driver, ntfsmount.
The improvements includes functionality, quality and performance enhancements.

%package -n ntfsprogs
Summary:       NTFS filesystem utilities
Group:         System/Kernel and Hardware
Requires:      %{libname} = %{?epoch:%epoch:}%{version}-%{release}

%description -n ntfsprogs
NTFS filesystem utilities.

%package -n %{libname}
Summary:       NTFS-3G library
Group:         System/Libraries
Provides:      libntfs
Obsoletes:     libntfs < 1:2021.8.22

%description -n %{libname}
The NTFS-3G driver library.

%package -n %{libname}-devel
Summary:       Devel package for %{libname}
Group:         Development/Libraries
Requires:      %{libname} = %{?epoch:%epoch:}%{version}-%{release}
Provides:      libntfs-devel
Obsoletes:     libntfs-devel < 1:2021.8.22

%description -n %{libname}-devel
The NTFS-3G driver library.
This package contains static libraries and header files needed for development.

%debug_package

%prep
%setup -q
#%patch -p1

%build
%configure \
   --disable-ldconfig

%make

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
%makeinstall

rm -rf %{buildroot}%{_defaultdocdir}/ntfs-3g
rm -f  %{buildroot}/sbin/*

ln -s ../bin/ntfs-3g %{buildroot}%{_sbindir}/mount.ntfs

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%post -n ntfs-3g
tmpdir=`mktemp -d /tmp/%{name}.XXXXXX` || exit 1
trap 'ret=$?; rm -rf $tmpdir && exit $ret' 0
trap '(exit $?); exit' 1 2 13 15
tmpfstab=`env TMPDIR="" mktemp -p $tmpdir tmpfile.XXXXXX` || exit 1
[ -e /etc/fstab ] && cp /etc/fstab $tmpfstab || touch /etc/fstab
while read fs mount_point fstype options dump fsck_order ignore; do
   case $fs in
   /dev/*)
      [ "$fstype" = ntfs-3g ] && continue
      if [ "$fstype" != ntfs ]; then
         devdisk="${fs/[0-9]*/}"
         devfstype=$( /sbin/fdisk -l $devdisk 2>/dev/null | \
            sed -n "/^${fs//\//\\/}/{
               s,\*,,;  # remove the star (bootable partition)
               # select the 5th column (fs id)
               s/\([^ ]*[ ]*\)\{4\}\([^ ]*\).*/\2/p}" )
         [ "$devfstype" = 7 ] || continue
      fi
      options="noauto,users,umask=002"
      [ "$LANG" ] && options="$options,locale=$LANG"
      sed -i "\@^$fs[ \t]*@d" /etc/fstab 2>/dev/null
      echo "$fs $mount_point ntfs-3g $options 0 0" >> /etc/fstab
   ;;
   esac
done < $tmpfstab
> $tmpfstab
:

%postun -n ntfs-3g
#erase
if [ $1 -eq 0 ]; then
   tmpdir=`mktemp -d /tmp/%{name}.XXXXXX` || exit 1
   trap 'ret=$?; rm -rf $tmpdir && exit $ret' 0
   trap '(exit $?); exit' 1 2 13 15
   tmpfstab=`env TMPDIR="" mktemp -p $tmpdir tmpfile.XXXXXX` || exit 1
   [ -e /etc/fstab ] && cp /etc/fstab $tmpfstab || touch /etc/fstab
   while read fs mount_point fstype options dump fsck_order ignore; do
      case $fs in
      /dev/*)
         [ "$fstype" = ntfs-3g ] || continue
         options="noauto,user,ro,umask=002"
         sed -i "\@^$fs[ \t]*@d" /etc/fstab 2>/dev/null
         echo "$fs $mount_point auto $options 0 0" >> /etc/fstab
      ;;
      esac
   done < $tmpfstab
   > $tmpfstab
fi
:

%post   -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n ntfs-3g
%defattr(-,root,root)
%{_bindir}/ntfs-3g*
%{_bindir}/lowntfs-3g*
%{_sbindir}/mount.ntfs
%{_mandir}/man8/*ntfs-3g*
%doc AUTHORS COPYING.LIB CREDITS

%files -n ntfsprogs
%defattr(-,root,root)
%{_bindir}/ntfscat
%{_bindir}/ntfscluster
%{_bindir}/ntfscmp
%{_bindir}/ntfsfix
%{_bindir}/ntfsinfo
%{_bindir}/ntfsls
%{_sbindir}/mkfs.ntfs
%{_sbindir}/mkntfs
%{_sbindir}/ntfsclone
%{_sbindir}/ntfscp
%{_sbindir}/ntfslabel
%{_sbindir}/ntfsresize
%{_sbindir}/ntfsundelete
%{_mandir}/man8/mkfs.ntfs.8*
%{_mandir}/man8/mkntfs.8*
%{_mandir}/man8/ntfscat.8*
%{_mandir}/man8/ntfsclone.8*
%{_mandir}/man8/ntfscluster.8*
%{_mandir}/man8/ntfscmp.8*
%{_mandir}/man8/ntfscp.8*
%{_mandir}/man8/ntfsdecrypt.8*
%{_mandir}/man8/ntfsfallocate.8*
%{_mandir}/man8/ntfsfix.8*
%{_mandir}/man8/ntfsinfo.8*
%{_mandir}/man8/ntfslabel.8*
%{_mandir}/man8/ntfsls.8*
%{_mandir}/man8/ntfsprogs.8*
%{_mandir}/man8/ntfsrecover.8*
%{_mandir}/man8/ntfsresize.8*
%{_mandir}/man8/ntfssecaudit.8*
%{_mandir}/man8/ntfsusermap.8*
%{_mandir}/man8/ntfstruncate.8*
%{_mandir}/man8/ntfsundelete.8*
%{_mandir}/man8/ntfswipe.8*

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/libntfs-3g.so.*

%files -n %{libname}-devel
%defattr(-,root,root)
%{_includedir}/ntfs-3g
%{_libdir}/libntfs-3g.a
%{_libdir}/libntfs-3g.so
%{_libdir}/pkgconfig/libntfs-3g.pc
%doc ChangeLog NEWS README

%changelog
* Tue Nov 01 2022 Automatic Build System <autodist@mambasoft.it> 2022.10.3-1mamba
- automatic version update by autodist

* Tue Aug 16 2022 Silvan Calarco <silvan.calarco@mambasoft.it> 2022.5.17-2mamba
- rebuilt with hwinfo 22.1

* Thu May 26 2022 Automatic Build System <autodist@mambasoft.it> 2022.5.17-1mamba
- automatic version update by autodist

* Sat Dec 18 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 2021.8.22-2mamba
- fix mounting from kde by providing again %{_sbindir}/mount.ntfs symlink

* Mon Sep 13 2021 Automatic Build System <autodist@mambasoft.it> 2021.8.22-1mamba
- automatic version update by autodist

* Thu Mar 30 2017 Automatic Build System <autodist@mambasoft.it> 2017.3.23-1mamba
- automatic version update by autodist

* Tue Mar 22 2016 Automatic Build System <autodist@mambasoft.it> 2016.2.22-1mamba
- automatic version update by autodist

* Sat Apr 18 2015 Automatic Build System <autodist@mambasoft.it> 2015.3.14-1mamba
- automatic version update by autodist

* Tue Mar 04 2014 Automatic Build System <autodist@mambasoft.it> 2014.2.15-1mamba
- automatic version update by autodist

* Fri Jan 25 2013 Automatic Build System <autodist@mambasoft.it> 2013.1.13-1mamba
- automatic version update by autodist

* Mon Jan 23 2012 Automatic Build System <autodist@mambasoft.it> 2012.1.15-1mamba
- automatic version update by autodist

* Thu Apr 28 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2011.4.12-2mamba
- added mount.ntfs symlink to mount.ntfs-3g to set automatic r/w mounts

* Wed Apr 27 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2011.4.12-1mamba
- update to 2011.4.12 (with ntfs-3g + ntfsprogs merge)

* Tue Jan 25 2011 Automatic Build System <autodist@mambasoft.it> 2011.1.15-1mamba
- automatic update by autodist

* Fri Oct 08 2010 Automatic Build System <autodist@mambasoft.it> 2010.10.2-1mamba
- automatic update to 2010.10.2 by autodist

* Mon Aug 09 2010 Automatic Build System <autodist@mambasoft.it> 2010.8.8-1mamba
- automatic update to 2010.8.8 by autodist

* Sat May 22 2010 Automatic Build System <autodist@mambasoft.it> 2010.5.16-1mamba
- automatic update to 2010.5.16 by autodist

* Sun Apr 11 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2010.3.6-2mamba
- removed duplicates of library in libntfs-3g-devel

* Mon Mar 29 2010 Stefano Cotta Ramusino <stefano.cotta@openmamba.org> 2010.3.6-1mamba
- update to 2010.3.6

* Mon Jan 18 2010 Automatic Build System <autodist@mambasoft.it> 2010.1.16-1mamba
- automatic update to 2010.1.16 by autodist

* Tue Nov 17 2009 Automatic Build System <autodist@mambasoft.it> 2009.11.14-1mamba
- automatic update to 2009.11.14 by autodist

* Fri Apr 03 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2009.4.4-1mamba
- automatic update to 2009.4.4 by autodist

* Fri Mar 27 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2009.3.8-1mamba
- automatic update to 2009.3.8 by autodist

* Thu Feb 12 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2009.2.1-1mamba
- automatic update to 2009.2.1 by autodist

* Fri Jan 23 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2009.1.1-1mamba
- automatic update to 2009.1.1 by autodist

* Mon Dec 01 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 1.5130-1mamba
- automatic update to 1.5130 by autodist

* Tue Oct 14 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 1.5012-1mamba
- automatic update to 1.5012 by autodist

* Fri Sep 19 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 1.2918-1mamba
- automatic update to 1.2918 by autodist

* Fri Aug 29 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 1.2812-1mamba
- update to 1.2812

* Mon Mar 10 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 1.2310-1mamba
- update to 1.2310

* Sat Nov 17 2007 Stefano Cotta Ramusino <stefano.cotta@openmamba.org> 1.1104-1mamba
- update to 1.1104

* Sat Aug 25 2007 Stefano Cotta Ramusino <stefano.cotta@openmamba.org> 1.810-1mamba
- update to 1.810
- enabled hal backends to use ntfs-3g instead of standard ntfs driver

* Sun May 27 2007 Stefano Cotta Ramusino <stefano.cotta@openmamba.org> 1.516-2mamba
- bumped to epoch 1
- added %%post and %%postun scripts to enable/disable writing on ntfs partitions

* Mon May 21 2007 Stefano Cotta Ramusino <stefano.cotta@openmamba.org> 1.516-1mamba
- update to 1.516

* Wed Apr 25 2007 Stefano Cotta Ramusino <stefano.cotta@openmamba.org> 1.417-1mamba
- update to 1.417

* Mon Jul 17 2006 Stefano Cotta Ramusino <stefano.cotta@qilinux.it> 20070714-1qilnx
- package created by autospec
